@@ -1,7 +1,7 @@
 /*
  * Copyright 2005-2008 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
- * $Header: /var/cvsroot/gentoo-projects/portage-utils/main.c,v 1.207 2011/12/19 04:39:24 vapier Exp $
+ * $Header: /var/cvsroot/gentoo-projects/portage-utils/main.c,v 1.214 2011/12/22 20:26:20 vapier Exp $
  *
  * Copyright 2005-2008 Ned Ludd        - <solar@gentoo.org>
  * Copyright 2005-2008 Mike Frysinger  - <vapier@gentoo.org>
@@ -207,7 +207,7 @@ static char eat_file_at(int dfd, const char *file, char *buf, const size_t bufsi
 	int fd;
 	char ret;
 
-	if ((fd = openat(dfd, file, O_RDONLY)) == -1) {
+	if ((fd = openat(dfd, file, O_CLOEXEC|O_RDONLY)) == -1) {
 		buf[0] = '\0';
 		return 0;
 	}
@@ -458,7 +458,7 @@ static void strincr_var(const char *name, const char *s, char **value, size_t *v
 	memcpy(nv, s, len + 1);
 
 	while ((p = strstr(nv, "-*")) != NULL)
-		memset(*value, ' ', p - *value);
+		memset(*value, ' ', p - *value + 2);
 
 	/* This function is mainly used by the startup code for parsing
 		make.conf and stacking variables remove.
@@ -531,20 +531,28 @@ _q_static void set_portage_env_var(env_vars *var, const char *value)
 }
 
 /* Helper to read a portage env file (e.g. make.conf) */
-_q_static void read_portage_env_file(const char *file, env_vars vars[])
+_q_static void read_portage_env_file(const char *configroot, const char *file, env_vars vars[])
 {
-	size_t i, buflen, line;
+	size_t i, buflen, line, configroot_len, file_len;
 	FILE *fp;
 	char *buf, *s, *p;
 
 	IF_DEBUG(fprintf(stderr, "profile %s\n", file));
 
-	fp = fopen(file, "r");
+	configroot_len = strlen(configroot);
+	file_len = strlen(file);
+	buflen = configroot_len + file_len + 1;
+	buf = xmalloc(buflen);
+
+	memcpy(buf, configroot, configroot_len);
+	memcpy(buf + configroot_len, file, file_len);
+	buf[buflen - 1] = '\0';
+
+	fp = fopen(buf, "r");
 	if (fp == NULL)
-		return;
+		goto done;
 
 	line = 0;
-	buf = NULL;
 	while (getline(&buf, &buflen, fp) != -1) {
 		++line;
 		rmspace(buf);
@@ -552,8 +560,27 @@ _q_static void read_portage_env_file(const char *file, env_vars vars[])
 			continue;
 
 		/* Handle "source" keyword */
-		if (!strncmp(buf, "source ", 7))
-			read_portage_env_file(buf + 7, vars);
+		if (!strncmp(buf, "source ", 7)) {
+			const char *sfile = buf + 7;
+
+			if (sfile[0] != '/') {
+				/* handle relative paths */
+				size_t file_path_len, source_len;
+
+				s = strrchr(file, '/');
+				file_path_len = s - file + 1;
+				source_len = strlen(sfile);
+
+				if (buflen <= source_len + file_path_len)
+					buf = xrealloc(buf, buflen = source_len + file_path_len + 1);
+				memmove(buf + file_path_len, buf + 7, source_len + 1);
+				memcpy(buf, file, file_path_len);
+				sfile = buf;
+			}
+
+			read_portage_env_file(configroot, sfile, vars);
+			continue;
+		}
 
 		/* look for our desired variables and grab their value */
 		for (i = 0; vars[i].name; ++i) {
@@ -607,8 +634,9 @@ _q_static void read_portage_env_file(const char *file, env_vars vars[])
 		}
 	}
 
-	free(buf);
 	fclose(fp);
+ done:
+	free(buf);
 }
 
 /* Helper to recursively read stacked make.defaults in profiles */
@@ -619,8 +647,6 @@ static void read_portage_profile(const char *configroot, const char *profile, en
 	char buf[BUFSIZE], *s;
 
 	/* initialize the base profile path */
-	if (!configroot)
-		configroot = "";
 	configroot_len = strlen(configroot);
 	profile_len = strlen(profile);
 	sub_len = 1024;	/* should be big enough for longest line in "parent" */
@@ -633,21 +659,22 @@ static void read_portage_profile(const char *configroot, const char *profile, en
 
 	/* first consume the profile's make.defaults */
 	strcpy(sub_file, "make.defaults");
-	read_portage_env_file(profile_file, vars);
+	read_portage_env_file("", profile_file, vars);
 
 	/* now walk all the parents */
 	strcpy(sub_file, "parent");
 	if (eat_file(profile_file, buf, sizeof(buf)) == 0)
-		return;
+		goto done;
 	rmspace(buf);
 
 	s = strtok(buf, "\n");
 	while (s) {
 		strncpy(sub_file, s, sub_len);
-		read_portage_profile(NULL, profile_file, vars);
+		read_portage_profile("", profile_file, vars);
 		s = strtok(NULL, "\n");
 	}
 
+ done:
 	free(profile_file);
 }
 
@@ -656,12 +683,6 @@ void initialize_portage_env(void)
 	size_t i;
 	const char *s;
 
-	static const char * const files[] = {
-		EPREFIX "etc/make.globals",
-		EPREFIX "usr/share/portage/config/make.globals",
-		EPREFIX "etc/make.conf",
-		EPREFIX "etc/portage/make.conf",
-	};
 	bool nocolor = 0;
 
 	env_vars *var;
@@ -682,16 +703,16 @@ void initialize_portage_env(void)
 		_Q_EVS(STR,  ACCEPT_LICENSE,      accept_license,      "")
 		_Q_EVS(ISTR, INSTALL_MASK,        install_mask,        "")
 		_Q_EVS(STR,  ARCH,                portarch,            "")
-		_Q_EVS(ISTR, CONFIG_PROTECT,      config_protect,      EPREFIX "etc")
+		_Q_EVS(ISTR, CONFIG_PROTECT,      config_protect,      CONFIG_EPREFIX "etc")
 		_Q_EVS(ISTR, CONFIG_PROTECT_MASK, config_protect_mask, "")
 		_Q_EVB(BOOL, NOCOLOR,             nocolor,             0)
 		_Q_EVS(ISTR, FEATURES,            features,            "noman noinfo nodoc")
-		_Q_EVS(STR,  EPREFIX,             eprefix,             EPREFIX)
-		_Q_EVS(STR,  PORTDIR,             portdir,             EPREFIX "usr/portage")
+		_Q_EVS(STR,  EPREFIX,             eprefix,             CONFIG_EPREFIX)
+		_Q_EVS(STR,  PORTDIR,             portdir,             CONFIG_EPREFIX "usr/portage")
 		_Q_EVS(STR,  PORTAGE_BINHOST,     binhost,             DEFAULT_PORTAGE_BINHOST)
-		_Q_EVS(STR,  PORTAGE_TMPDIR,      port_tmpdir,         EPREFIX "var/tmp/portage/")
-		_Q_EVS(STR,  PKGDIR,              pkgdir,              EPREFIX "usr/portage/packages/")
-		_Q_EVS(STR,  Q_VDB,               portvdb,             EPREFIX "var/db/pkg")
+		_Q_EVS(STR,  PORTAGE_TMPDIR,      port_tmpdir,         CONFIG_EPREFIX "var/tmp/portage/")
+		_Q_EVS(STR,  PKGDIR,              pkgdir,              CONFIG_EPREFIX "usr/portage/packages/")
+		_Q_EVS(STR,  Q_VDB,               portvdb,             CONFIG_EPREFIX "var/db/pkg")
 		{ NULL, 0, _Q_BOOL, { NULL }, 0, NULL, }
 
 #undef _Q_EV
@@ -704,16 +725,19 @@ void initialize_portage_env(void)
 			*var->value.s = xstrdup(var->default_value);
 	}
 
-	/* walk all the stacked profiles */
+	/* figure out where to find our config files */
 	s = getenv("PORTAGE_CONFIGROOT");
 	if (!s)
 		s = "/";
-	read_portage_profile(s, EPREFIX "etc/make.profile", vars_to_read);
-	read_portage_profile(s, EPREFIX "etc/portage/make.profile", vars_to_read);
+
+	/* walk all the stacked profiles */
+	read_portage_profile(s, CONFIG_EPREFIX "etc/make.profile", vars_to_read);
+	read_portage_profile(s, CONFIG_EPREFIX "etc/portage/make.profile", vars_to_read);
 
 	/* now read all the config files */
-	for (i = 0; i < ARRAY_SIZE(files); ++i)
-		read_portage_env_file(files[i], vars_to_read);
+	read_portage_env_file("", CONFIG_EPREFIX "usr/share/portage/config/make.globals", vars_to_read);
+	read_portage_env_file(s, CONFIG_EPREFIX "etc/make.conf", vars_to_read);
+	read_portage_env_file(s, CONFIG_EPREFIX "etc/portage/make.conf", vars_to_read);
 
 	/* finally, check the env */
 	for (i = 0; vars_to_read[i].name; ++i) {
@@ -721,14 +745,6 @@ void initialize_portage_env(void)
 		s = getenv(var->name);
 		if (s != NULL)
 			set_portage_env_var(var, s);
-		if (getenv("DEBUG") IF_DEBUG(|| 1)) {
-			fprintf(stderr, "%s = ", var->name);
-			switch (var->type) {
-			case _Q_BOOL: fprintf(stderr, "%i\n", *var->value.b); break;
-			case _Q_STR:
-			case _Q_ISTR: fprintf(stderr, "%s\n", *var->value.s); break;
-			}
-		}
 	}
 
 	/* expand any nested variables e.g. PORTDIR=${EPREFIX}/usr/portage */
@@ -795,6 +811,18 @@ void initialize_portage_env(void)
 		}
 	}
 
+	if (getenv("DEBUG") IF_DEBUG(|| 1)) {
+		for (i = 0; vars_to_read[i].name; ++i) {
+			var = &vars_to_read[i];
+			fprintf(stderr, "%s = ", var->name);
+			switch (var->type) {
+			case _Q_BOOL: fprintf(stderr, "%i\n", *var->value.b); break;
+			case _Q_STR:
+			case _Q_ISTR: fprintf(stderr, "%s\n", *var->value.s); break;
+			}
+		}
+	}
+
 	/* Make sure ROOT always ends in a slash */
 	var = &vars_to_read[0];
 	if ((*var->value.s)[var->value_len - 1] != '/') {
@@ -1177,7 +1205,7 @@ int main(int argc, char **argv)
 
 #ifdef ENABLE_NLS	/* never tested */
 	setlocale(LC_ALL, "");
-	bindtextdomain(argv0, EPREFIX "usr/share/locale");
+	bindtextdomain(argv0, CONFIG_EPREFIX "usr/share/locale");
 	textdomain(argv0);
 #endif
 #if 1
